@@ -4,13 +4,14 @@
 #include <QDialog>
 #include <QCheckBox>
 #include "core/player.h"
+#include "controls/dialogwindow.h"
 #include "randomnumberpicker.h"
 
 namespace Ui {
     class BonusDisciplineWindow;
 }
 
-class BonusDisciplineWindow : public QDialog
+class BonusDisciplineWindow : public DialogWindow
 {
     Q_OBJECT
 
