@@ -541,7 +541,8 @@ void BookWindow::DoChoice(int number)
     int section = m_Section->Number;
 
     if (!choice->Script.isEmpty()){
-        ExecuteChoiceScript(choice);
+        if (!ExecuteChoiceScript(choice) && choice->Target == 0)
+            choice->Abort();
         if (m_Player->IsDead())
             choice->Abort();
     }
@@ -637,13 +638,13 @@ void BookWindow::UpdateToolbar()
     ui->lblCrowns->setText(QString::number(m_Player->GoldCrowns));
 }
 
-void BookWindow::ExecuteChoiceScript(Choice* choice)
+bool BookWindow::ExecuteChoiceScript(Choice* choice)
 {
     QScriptValue objectValue = m_Engine.newQObject(choice);
     m_Engine.globalObject().setProperty("Choice", objectValue);
 
     choice->Accept();
-    ExecuteScript("ChoiceScript", choice->Script);
+    return ExecuteScript("ChoiceScript", choice->Script);
 }
 
 bool BookWindow::ExecuteSystemScript(QString name)
@@ -912,6 +913,21 @@ bool BookWindow::Load(QString filename)
         m_Book = NULL;
         return false;
     }else{
+        // Check book minimum interpreter version:
+        VersionClass interpreter;
+        interpreter.FromString(QCoreApplication::applicationVersion());
+        if (m_Book->MinInterpreterVersion > interpreter){
+            QMessageBox msgBox(this);
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.setText(QString("This book needs version %1 (you have %2)")
+                           .arg(m_Book->MinInterpreterVersion.ToString())
+                           .arg(interpreter.ToString()));
+            msgBox.exec();
+
+            delete m_Book;
+            m_Book = NULL;
+            return false;
+        }
         LoadBookFunctions();
         int sectionNumber = settings.value("section").toInt();
         m_Section = m_Book->Sections[sectionNumber];
@@ -1425,7 +1441,8 @@ void BookWindow::BookInfoSlot()
 
 void BookWindow::BookRestartSlot()
 {
-    if (CommonStatic::ConfirmMessage(this, "Confirm", "Do you want to restart the book?") == QMessageBox::Yes){
+    if (CommonStatic::ConfirmMessage(this, "Confirm",
+                                     QString("Do you want to restart '%1'?").arg(m_Book->Title)) == QMessageBox::Yes){
         Load(GetBookSaveFilename(m_Book->Number));
         QScriptValue objectValue = m_Engine.newQObject(m_Player);
         m_Engine.globalObject().setProperty("Player", objectValue);
