@@ -2,10 +2,9 @@
 #include "ui_chooseitemwindow.h"
 #include <QLabel>
 #include <QPushButton>
-#include <QCloseEvent>
 
 ChooseItemWindow::ChooseItemWindow(QWidget *parent, Player* player, int mode) :
-    QDialog(parent),
+    DialogWindow(parent),
     ui(new Ui::ChooseItemWindow)
 {
     ui->setupUi(this);
@@ -13,7 +12,7 @@ ChooseItemWindow::ChooseItemWindow(QWidget *parent, Player* player, int mode) :
     setAttribute(Qt::WA_Maemo5AutoOrientation);
 #endif
 
-    m_Close = false;
+    SetCanClose(false);
     m_Selected = NULL;
     m_Player = player;
     m_Mode = mode;
@@ -221,15 +220,5 @@ void ChooseItemWindow::SelectedSlot()
         break;
     }
 
-    m_Close = true;
     accept();
 }
-
-
-void ChooseItemWindow::closeEvent(QCloseEvent* event)
-{
-    if (m_Close)
-        event->accept();
-    else
-        event->ignore();
-}
