@@ -2,13 +2,14 @@
 #define CHOOSEITEMWINDOW_H
 
 #include <QDialog>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 
 namespace Ui {
     class ChooseItemWindow;
 }
 
-class ChooseItemWindow : public QDialog
+class ChooseItemWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -26,14 +27,10 @@ public:
 
     Item* SelectedItem() { return m_Selected; }
 
-protected:
-    void closeEvent(QCloseEvent *event);
-
 private:
     Ui::ChooseItemWindow *ui;
 
     int m_Mode;
-    bool m_Close;
     Player* m_Player;
     Item* m_Selected;
 
