@@ -9,15 +9,19 @@ DialogWindow::DialogWindow(QWidget *parent) :
     m_Loop = NULL;
     m_CanClose = false;
     m_Result = QDialog::Rejected;
-#ifndef Q_WS_MAEMO_5
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5AutoOrientation);
+#else
     setWindowModality(Qt::WindowModal);
 #endif
 }
 
 DialogWindow::~DialogWindow()
 {
-    if (m_Loop)
+    if (m_Loop){
         delete m_Loop;
+        m_Loop = NULL;
+    }
 }
 
 int DialogWindow::exec()
