@@ -182,6 +182,16 @@ void Weapon::AddClass(int iClass)
     SetProperty("Classes", str);
 }
 
+bool Weapon::HasClass(QString value)
+{
+    return Classes().contains(GetClass(value));
+}
+
+bool Weapon::HasClass(int value)
+{
+    return Classes().contains(value);
+}
+
 QList<int> Weapon::Classes()
 {
     QList<int> res;
