@@ -32,11 +32,11 @@ Player::Player(const Player& player) :
     Properties = QHash<QString, QString>(player.Properties);
 }
 
-QList<Weapon*> Player::Weapons()
+QList<Weapon*> Player::Weapons(bool includeSpecial)
 {
     QList<Weapon*> res;
     foreach (Item* i, Items){
-        if (i->GetIsWeapon() && !i->GetIsSpecial())
+        if (i->GetIsWeapon() && (!includeSpecial || !i->GetIsSpecial()))
             res.append((Weapon*)i);
     }
     return res;
@@ -918,7 +918,7 @@ void Player::RemoveWeapon(QString name)
 {
     if (!name.isEmpty()){
         Weapon* found = NULL;
-        foreach(Weapon* w, Weapons()){
+        foreach(Weapon* w, Weapons(true)){
             if (QString::compare(w->Name, name) == 0){
                 found = w;
                 break;
