@@ -32,7 +32,7 @@ public:
     QList<KaiDiscipline*> KaiDisciplines;
     void RemoveDiscipline(QString name);
 
-    QList<Weapon*> Weapons();
+    QList<Weapon*> Weapons(bool includeSpecial=false);
     QList<Item*> BackpackItems();
     QList<Item*> SpecialItems();
     QList<Item*> Items;
